@@ -7,7 +7,7 @@ use utf8;
 
 use parent qw(Tickit::ContainerWidget);
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 =head1 NAME
 
@@ -15,7 +15,7 @@ Tickit::Widget::Layout::Desktop - provides a holder for "desktop-like" widget be
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -493,6 +493,17 @@ sub close_all {
 	$_->close for reverse @{$self->window->{child_windows}};
 }
 
+sub close_panel {
+	my ($self, $panel) = @_;
+	my $rect = $panel->window->rect;
+	my $addr = refaddr($panel);
+	List::UtilsBy::extract_by { refaddr($_) == $addr }@{ $self->{widgets} };
+	$panel->window->close;
+	$self->window->tickit->later(sub {
+		$self->window->expose($rect);
+	})
+}
+
 # Tickit::Widget
 sub focus_next {
 	my ($self) = shift;
